import axios from 'axios'
import qs from 'qs'
import { getToken, refreshToken } from './generateOrRefreshToken'
import { message } from 'ant-design-vue'
const BASE_URL = process.env.VUE_APP_API_URL
let loadingInstance // 创建Loading 的实例
// 配置发送请求前的拦截器，设置token信息
axios.interceptors.request.use((config) => {
  // loading开始loadingInstance.start()
  let isRefreshToken = new Date().getTime() - localStorage.getItem(`start_time_${localStorage.getItem('orgId')}`) < localStorage.getItem(`expires_in_${localStorage.getItem('orgId')}`) - 5 * 60 * 1000
  if (isRefreshToken) {
    config.headers['Authorization'] = `Bearer ${localStorage.getItem(`access_token_${localStorage.getItem('orgId')}`)}`
    return config
  } else {
    return new Promise((resolve, reject) => {
      refreshToken().then((res) => {
        console.log('res', res)
      }).catch((err) => {
        console.log(err)
      })
    })
  }
}, (error) => {
  // 出错，也要loading结束
  loadingInstance.close()
  return Promise.reject(error)
})
// 配置请求返回的拦截器，
axios.interceptors.response.use(res => {
  // if (res.data.resultCode === 0) {
  return Promise.resolve(res)
  // } else {
  //   return Promise.reject()
  // }
}, err => {
  return new Promise((resolve, reject) => {
    console.log(err)
    if (err && err.response) {
      switch (err.response.status) {
        case 401:
          message.error('网络异常请重试')
          refreshToken().then(res => {
            console.log('refreshToken1', res)
            resolve(err)
          })
          break
        case 426:
          message.error('网络异常请重试')
          getToken().then((res) => {
            resolve(err)
          })
          break
        case 504:
          message.error('系统异常')
          resolve(err)
          break
        case 500:
          message.error('系统繁忙')
          resolve(err)
          break
        default:
          message.error('未知问题')
          resolve(err)
          reject(new Error(err))
      }
    } else {
      message.error('未知问题')
      resolve(err)
    }
  })
})
const $http = {
  post: (url, data) => {
    return new Promise((resolve, reject) => {
      // let postData
      // if (data === undefined) {
      //   postData = {
      //     orgId: localStorage.getItem('orgId')
      //   }
      // } else {
      //   postData = data
      //   postData.orgId = localStorage.getItem('orgId')
      // }
      let postData = data === undefined ? '' : data
      axios.post(`${BASE_URL}${url}`, postData, {
        headers: {
          'Content-Type': 'application/json; charset=UTF-8'
        }
      }).then((res) => {
        return resolve(res)
      })
    })
  },
  get: (url, data) => {
    return new Promise((resolve, reject) => {
      let getData = data === undefined ? '' : qs.stringify(data)
      axios.get(`${BASE_URL}${url}?${getData}`).then((res) => {
        return resolve(res)
      })
    })
  },
  delete: (url, data) => {
    return new Promise((resolve, reject) => {
      let getData = data === undefined ? '' : qs.stringify(data)
      axios.delete(`${BASE_URL}${url}?${getData}`).then((res) => {
        return resolve(res)
      })
    })
  }
}
export { $http }
