import * as dd from 'dingtalk-jsapi'
import axios from 'axios'
import qs from 'qs'
import { getToken, refreshToken, ispermission } from './generateOrRefreshToken'
let basurl = process.env.VUE_APP_API_URL
// axios.defaults.headers['Authorization'] = `Bearer ${localStorage.getItem('token')}`
const config = {
  ddconfig: () => {
    let senddate = qs.stringify({
      // version: MINGPAY_CONSTANT.MINGPAY_CONSTANT_VERSION,
      url: location.href.replace(window.location.hash, ''),
      orgId: localStorage.getItem('orgId')
    })
    return axios.post(`${basurl}/mingpay/v1/skipAuth/getJsAuthenticationParameter?${senddate}`).then((res) => {
      let timeStamp = res.data.data.timeStamp
      let nonceStr = res.data.data.nonceStr
      let signature = res.data.data.signature
      let agentId = res.data.data.agentId
      dd.config({
        agentId: agentId, // 必填，微应用ID
        corpId: localStorage.getItem('orgId'), // 必填，企业ID
        timeStamp: timeStamp, // 必填，生成签名的时间戳
        nonceStr: nonceStr, // 必填，生成签名的随机串
        signature: signature, // 必填，签名
        type: 0, // 0/1选填。0表示微应用的jsapi,1表示服务窗的jsapi；不填默认为0。该参数从dingtalk.js的0.8.3版本开始支持
        jsApiList: [
          'biz.contact.choose',
          'biz.contact.complexPicker'
        ] // 必填，需要使用的jsapi列表，注意：不要带dd。
      })
      sessionStorage.setItem('isFirstAction', true)
      dd.error(function (error) {
        console.log('dd error: ' + JSON.stringify(error))
        return 'no'
      })
    })
  },
  // dd.ready参数为回调函数，在环境准备就绪时触发，jsapi的调用需要保证在该回调函数触发后调用，否则无效。
  ddready: (item, hasSelect) => {
    return new Promise((resolve, reject) => {
      dd.ready(function () {
        return resolve(config[item](hasSelect))
      })
    })
  },
  ddpermission: () => {
    // 判断当前用户是否有权限登陆后台
    return new Promise((resolve, reject) => {
      ispermission().then(res => {
        // 判断登陆状态
        if (res === 40003) {
          resolve('noPermission')
        } else {
          let isRefreshToken = new Date().getTime() - localStorage.getItem(`start_time_${localStorage.getItem('orgId')}`) < localStorage.getItem(`expires_in_${localStorage.getItem('orgId')}`) - 5 * 60 * 1000
          if (localStorage.getItem(`access_token_${localStorage.getItem('orgId')}`) && isRefreshToken) {
            resolve('ok')
          } else if (localStorage.getItem(`refresh_token_${localStorage.getItem('orgId')}`)) {
            refreshToken().then((res) => {
              if (res === 'ok') {
                resolve('ok')
              }
            })
          } else {
            getToken().then((res) => {
              if (res === 'noPermission') {
                resolve('noPermission')
              } else {
                resolve('ok')
              }
            })
          }
        }
      })
    })
  },
  ddchooseOne: () => {
    return new Promise((resolve, reject) => {
      dd.biz.contact.choose({
        multiple: false, // 是否多选：true多选 false单选； 默认true
        users: [], // 默认选中的用户列表，员工userid；成功回调中应包含该信息
        corpId: localStorage.getItem('orgId'), // 企业id
        max: 1, // 人数限制，当multiple为true才生效，可选范围1-1500
        onSuccess: function (data) {
          return resolve(data)
        },
        onFail: function (err) {
          return reject(err)
        }
      })
    })
  },
  ddchoose: () => {
    return new Promise((resolve, reject) => {
      dd.biz.contact.complexPicker({
        title: '人员选择', // 标题
        corpId: localStorage.getItem('orgId'), // 企业的corpId
        multiple: true, // 是否多选
        limitTips: '超出了', // 超过限定人数返回提示
        maxUsers: 1000, // 最大可选人数
        pickedUsers: [], // 已选用户
        pickedDepartments: [], // 已选部门
        disabledUsers: [], // 不可选用户
        disabledDepartments: [], // 不可选部门
        requiredUsers: [], // 必选用户（不可取消选中状态）
        requiredDepartments: [], // 必选部门（不可取消选中状态）
        appId: localStorage.getItem('agentId'), // 微应用的Id
        permissionType: 'GLOBAL', // 可添加权限校验，选人权限，目前只有GLOBAL这个参数
        responseUserOnly: false, // 返回人，或者返回人和部门
        startWithDepartmentId: -1, // 仅支持0和-1
        onSuccess: function (result) {
          return resolve(result)
        },
        onFail: function (err) {
          return reject(err)
        }
      })
    })
  },
  ddchooseTen: (hasSelect) => {
    console.log(hasSelect.userHasRoles, 'hasSelect')
    return new Promise((resolve, reject) => {
      dd.biz.contact.complexPicker({
        title: '人员选择', // 标题
        corpId: localStorage.getItem('orgId'), // 企业的corpId
        multiple: true, // 是否多选
        limitTips: '超出了', // 超过限定人数返回提示
        maxUsers: 10, // 最大可选人数
        pickedUsers: hasSelect, // 已选用户
        pickedDepartments: [], // 已选部门
        disabledUsers: [], // 不可选用户
        disabledDepartments: [], // 不可选部门
        requiredUsers: [], // 必选用户（不可取消选中状态）
        requiredDepartments: [], // 必选部门（不可取消选中状态）
        appId: localStorage.getItem('agentId'), // 微应用的Id
        permissionType: 'GLOBAL', // 可添加权限校验，选人权限，目前只有GLOBAL这个参数
        responseUserOnly: false, // 返回人，或者返回人和部门
        startWithDepartmentId: -1, // 仅支持0和-1
        onSuccess: function (result) {
          return resolve(result)
        },
        onFail: function (err) {
          return reject(err)
        }
      })
    })
  }
}

export { config }
