import Vue from 'vue'
import Router from 'vue-router'
import Home from './components/common/Home.vue'
// import { resolve } from 'any-promise';

Vue.use(Router)

export default new Router({
  // mode: 'history',
  // base: process.env.BASE_URL,
  routes: [
    {
      path: '/',
      redirect: '/dashboard'
    },
    {
      path: '/home',
      name: 'home',
      component: Home,
      children: [
        {
          path: '/dashboard',
          name: 'dashboard',
          component: resolve => require(['./components/pages/Dashboard.vue'], resolve)
        },
        {
          path: '/canteenManagementHome',
          name: 'canteenManagementHome',
          component: resolve => require(['./components/pages/CanteenManagement/CanteenManagementHome.vue'], resolve),
          children: [
            {
              path: '/classificationOfDishes',
              name: 'classificationOfDishes',
              meta: { title: '食堂管理/菜品分类' },
              component: resolve => require(['./components/pages/CanteenManagement/ClassificationOfDishes.vue'], resolve)
            },
            {
              path: '/menuManagement',
              name: 'menuManagement',
              meta: { title: '食堂管理/菜单管理' },
              component: resolve => require(['./components/pages/CanteenManagement/MenuManagement.vue'], resolve)
            },
            {
              path: '/consumptionOrder',
              name: 'consumptionOrder',
              meta: { title: '食堂管理/消费订单' },
              component: resolve => require(['./components/pages/CanteenManagement/ConsumptionOrder.vue'], resolve)
            },
            {
              path: '/consumptionStatistics',
              name: 'consumptionStatistics',
              meta: { title: '食堂管理/消费统计' },
              component: resolve => require(['./components/pages/CanteenManagement/ConsumptionStatistics.vue'], resolve)
            }
          ]
        },
        {
          path: '/paymentManagementHome',
          name: 'paymentManagementHome',
          component: resolve => require(['./components/pages/PaymentManagement/PaymentManagementHome.vue'], resolve),
          children: [
            {
              path: '/accountManagement',
              name: 'accountManagement',
              meta: { title: '支付管理/账户中心' },
              component: resolve => require(['./components/pages/PaymentManagement/AccountManagement.vue'], resolve)
            },
            {
              path: '/cashierManagement',
              name: 'cashierManagement',
              meta: { title: '支付管理/设置收银员' },
              component: resolve => require(['./components/pages/PaymentManagement/CashierManagement.vue'], resolve)
            },
            {
              path: '/SetAdministrators',
              name: 'SetAdministrators',
              meta: { title: '支付管理/设置管理员' },
              component: resolve => require(['./components/pages/PaymentManagement/SetAdministrators.vue'], resolve)
            },
            {
              path: '/allowancePayment',
              name: 'allowancePayment',
              meta: { title: '支付管理/津贴发放' },
              component: resolve => require(['./components/pages/PaymentManagement/AllowancePayment.vue'], resolve)
            },
            {
              path: '/operationLog',
              name: 'operationLog',
              meta: { title: '支付管理/操作日志' },
              component: resolve => require(['./components/pages/PaymentManagement/OperationLog.vue'], resolve)
            },
            {
              path: '/rechargeRecord',
              name: 'rechargeRecord',
              meta: { title: '支付管理/充值记录' },
              component: resolve => require(['./components/pages/PaymentManagement/RechargeRecord.vue'], resolve)
            },
            {
              path: '/recordsOfConsumption',
              name: 'recordsOfConsumption',
              meta: { title: '支付管理/消费记录' },
              component: resolve => require(['./components/pages/PaymentManagement/RecordsOfConsumption.vue'], resolve)
            },
            {
              path: '/systemReconciliation',
              name: 'systemReconciliation',
              meta: { title: '支付管理/系统对账' },
              component: resolve => require(['./components/pages/PaymentManagement/SystemReconciliation.vue'], resolve)
            },
            {
              path: '/viewAllowances',
              name: 'viewAllowances',
              meta: { title: '支付管理/账户中心/查看津贴' },
              component: resolve => require(['./components/pages/PaymentManagement/ViewAllowances.vue'], resolve)
            },
            {
              path: '/allowanceDetails',
              name: 'allowanceDetails',
              meta: { title: '支付管理/津贴发放/津贴详情' },
              component: resolve => require(['./components/pages/PaymentManagement/AllowanceDetails.vue'], resolve)
            },
            {
              path: '/paymentManagementSetting',
              name: 'paymentManagementSetting',
              meta: { title: '支付管理/设置中心' },
              component: resolve => require(['./components/pages/PaymentManagement/PaymentManagementSetting.vue'], resolve)
            }
          ]
        },
        {
          path: '/visitorManagementHome',
          name: 'visitorManagementHome',
          component: resolve => require(['./components/pages/VisitorManagement/VisitorManagementHome.vue'], resolve),
          children: [
            {
              path: '/historicalVisitors',
              name: 'historicalVisitors',
              meta: { title: '食堂管理/菜品分类' },
              component: resolve => require(['./components/pages/VisitorManagement/HistoricalVisitors.vue'], resolve)
            },
            {
              path: '/visitorSetting',
              name: 'visitorSetting',
              meta: { title: '食堂管理/菜单管理' },
              component: resolve => require(['./components/pages/VisitorManagement/VisitorSetting.vue'], resolve)
            }
          ]
        },
        {
          path: '/rightsManagementHome',
          name: 'rightsManagementHome',
          component: resolve => require(['./components/pages/rightsManagement/rightsManagementHome.vue'], resolve),
          children: [
            {
              path: '/rightsManagement',
              name: 'rightsManagement',
              meta: { title: '权限管理/角色管理' },
              component: resolve => require(['./components/pages/rightsManagement/rightsManagement.vue'], resolve)
            },
            {
              path: '/addOrRights',
              name: 'addOrRights',
              meta: { title: '权限管理/角色管理/增加角色' },
              component: resolve => require(['./components/pages/rightsManagement/addOrRights.vue'], resolve)
            }
          ]
        }
      ]
    },
    {
      path: '/noPermission',
      name: 'noPermission',
      component: resolve => require(['./components/pages/NoPermission.vue'], resolve)
    },
    {
      path: '/configError',
      name: 'configError',
      component: resolve => require(['./components/pages/ConfigError.vue'], resolve)
    },
    {
      path: '/*',
      redirect: '/accountManagement'
    }
  ]
})
